@@ -7,10 +7,10 @@ legit.core
 This module provides the basic functionality of legit.
 """
 
-import bootstrap
+from . import bootstrap
 del bootstrap
 
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 __author__ = 'Kenneth Reitz'
 __license__ = 'BSD'
 
